@@ -10,6 +10,7 @@ pub use super::feedback::*;
 pub use super::filter::*;
 pub use super::fir::*;
 pub use super::math::*;
+pub use super::moog::*;
 pub use super::noise::*;
 pub use super::oscillator::*;
 pub use super::oversample::*;
@@ -160,6 +161,7 @@ pub type U128 = numeric_array::typenum::U128;
 
 /// Constant node.
 /// Synonymous with `[dc]`.
+/// - Output(s): constant
 #[inline]
 pub fn constant<X: ConstantFrame<Sample = f64>>(x: X) -> An<Constant<X::Size, f64>>
 where
@@ -171,6 +173,7 @@ where
 /// Constant node.
 /// Synonymous with `constant`.
 /// (DC stands for "direct current", which is an electrical engineering term used with signals.)
+/// - Output(s): constant
 #[inline]
 pub fn dc<X: ConstantFrame<Sample = f64>>(x: X) -> An<Constant<X::Size, f64>>
 where
@@ -212,16 +215,29 @@ pub fn multipass<N: Size<f64>>() -> An<MultiPass<N, f64>> {
     An(MultiPass::new())
 }
 
-/// Timer node. An empty node that presents time as a parameter.
+/// Timer node. A node with no inputs or outputs that presents time as a parameter.
+/// It can be added to any node by stacking.
 #[inline]
 pub fn timer(tag: Tag) -> An<Timer<f64>> {
     An(Timer::new(DEFAULT_SR, tag))
 }
 
-/// Monitor node. Passes through input and retains the latest input as a parameter.
+/// Monitor node. Passes through input and presents as a parameter
+/// an aspect of the input signal according to the chosen metering mode.
+/// -Input 0: input signal
+/// -Output 0: input signal
 #[inline]
-pub fn monitor(tag: Tag) -> An<Monitor<f64>> {
-    An(Monitor::new(tag))
+pub fn monitor(meter: Meter, tag: Tag) -> An<Monitor<f64>> {
+    An(Monitor::new(tag, DEFAULT_SR, meter))
+}
+
+/// Meter node.
+/// Outputs a summary of the input according to the chosen metering mode.
+/// -Input 0: input signal
+/// -Output 0: input signal summary
+#[inline]
+pub fn meter(meter: Meter) -> An<MeterNode<f64>> {
+    An(MeterNode::new(DEFAULT_SR, meter))
 }
 
 /// Mono sink. Input is discarded.
@@ -331,7 +347,7 @@ pub fn lowpole_hz(f: f64) -> An<Lowpole<f64, f64, U1>> {
     super::prelude::lowpole_hz(f)
 }
 
-/// Allpole filter with adjustable delay (delay > 0) in samples at DC.
+/// Allpass filter with adjustable delay (delay > 0) in samples at DC.
 /// - Input 0: audio
 /// - Input 1: delay in samples
 /// - Output 0: filtered audio
@@ -340,7 +356,7 @@ pub fn allpole() -> An<Allpole<f64, f64, U2>> {
     An(Allpole::new(DEFAULT_SR, 1.0))
 }
 
-/// Allpole filter with delay (delay > 0) in samples at DC.
+/// Allpass filter with delay (delay > 0) in samples at DC.
 /// - Input 0: audio
 /// - Output 0: filtered audio
 #[inline]
@@ -383,6 +399,57 @@ pub fn resonator_hz(center: f64, bandwidth: f64) -> An<Resonator<f64, f64, U1>>
     super::prelude::resonator_hz(center, bandwidth)
 }
 
+/// Moog resonant lowpass filter.
+/// - Input 0: input signal
+/// - Input 1: cutoff frequency (Hz)
+/// - Input 2: Q
+/// - Output 0: filtered signal
+#[inline]
+pub fn moog() -> An<Moog<f64, f64, U3>> {
+    An(Moog::new(DEFAULT_SR, 1000.0, 0.1))
+}
+
+/// Moog resonant lowpass filter with fixed Q.
+/// - Input 0: input signal
+/// - Input 1: cutoff frequency (Hz)
+/// - Output 0: filtered signal
+#[inline]
+pub fn moog_q(
+    q: f64,
+) -> An<Pipe<f64, Stack<f64, MultiPass<U2, f64>, Constant<U1, f64>>, Moog<f64, f64, U3>>> {
+    (multipass::<U2>() | dc(q)) >> An(Moog::new(convert(DEFAULT_SR), 1000.0, q))
+}
+
+/// Moog resonant lowpass filter with fixed cutoff frequency and Q.
+/// - Input 0: input signal
+/// - Output 0: filtered signal
+#[inline]
+pub fn moog_hz(frequency: f64, q: f64) -> An<Moog<f64, f64, U1>> {
+    An(Moog::new(DEFAULT_SR, frequency, q))
+}
+
+/// Morphing filter that morphs between lowpass, peak and highpass modes.
+/// - Input 0: input signal
+/// - Input 1: center frequency (Hz)
+/// - Input 2: Q
+/// - Input 3: morph in -1...1 (-1 = lowpass, 0 = peak, 1 = highpass)
+/// - Output 0: filtered signal
+pub fn morph() -> An<super::prelude::Morph<f64, f64>> {
+    super::prelude::morph()
+}
+
+/// Morphing filter with center frequency `f`, Q value `q`, and morph `morph`
+/// (-1 = lowpass, 0 = peaking, 1 = highpass).
+/// - Input 0: input signal
+/// - Output 0: filtered signal
+pub fn morph_hz(
+    f: f64,
+    q: f64,
+    morph: f64,
+) -> An<Pipe<f64, Stack<f64, Pass<f64>, Constant<U3, f64>>, super::prelude::Morph<f64, f64>>> {
+    super::prelude::morph_hz(f, q, morph)
+}
+
 /// Control envelope from time-varying function `f(t)` with `t` in seconds.
 /// Spaces samples using pseudorandom jittering.
 /// Synonymous with `lfo`.
@@ -607,66 +674,91 @@ where
 /// Keeps a signal zero centered.
 /// Filter cutoff `c` is usually somewhere below the audible range.
 /// The default blocker cutoff is 10 Hz.
+/// - Input 0: input signal
+/// - Output 0: signal with DC removed.
 #[inline]
 pub fn dcblock_hz(c: f64) -> An<DCBlock<f64, f64>> {
     An(DCBlock::new(DEFAULT_SR, c))
 }
 
 /// Keeps a signal zero centered.
+/// - Input 0: input signal
+/// - Output 0: signal with DC removed.
 #[inline]
 pub fn dcblock() -> An<DCBlock<f64, f64>> {
     dcblock_hz(10.0)
 }
 
 /// Apply 10 ms of fade-in to signal at time zero.
+/// - Input 0: input signal
+/// - Output 0: signal with fade-in.
 #[inline]
 pub fn declick() -> An<Declick<f64, f64>> {
     super::prelude::declick()
 }
 
 /// Apply `t` seconds of fade-in to signal at time zero.
+/// - Input 0: input signal
+/// - Output 0: signal with fade-in.
 #[inline]
 pub fn declick_s(t: f64) -> An<Declick<f64, f64>> {
     super::prelude::declick_s(t)
 }
 
 /// Shape signal with a waveshaper function.
+/// - Input 0: input signal
+/// - Output 0: shaped signal
 #[inline]
 pub fn shape_fn<S: Fn(f64) -> f64>(f: S) -> An<ShaperFn<f64, S>> {
     super::prelude::shape_fn(f)
 }
 
-/// Shape signal.
+/// Shape signal according to shaping mode.
+/// - Input 0: input signal
+/// - Output 0: shaped signal
 #[inline]
 pub fn shape(mode: Shape<f64>) -> An<Shaper<f64>> {
     super::prelude::shape(mode)
 }
 
 /// Clip signal to -1...1.
+/// - Input 0: input signal
+/// - Output 0: clipped signal
 #[inline]
 pub fn clip() -> An<Shaper<f64>> {
     super::prelude::clip()
 }
 
 /// Clip signal to min...max.
+/// - Input 0: input signal
+/// - Output 0: clipped signal
 #[inline]
 pub fn clip_to(minimum: f64, maximum: f64) -> An<Shaper<f64>> {
     super::prelude::clip_to(minimum, maximum)
 }
 
 /// Equal power mono-to-stereo panner.
+/// - Input 0: input signal
+/// - Input 1: pan in -1...1 (left to right).
+/// - Output 0: left channel
+/// - Output 1: right channel
 #[inline]
 pub fn panner() -> An<Panner<f64, U2>> {
     An(Panner::new(0.0))
 }
 
 /// Fixed equal power mono-to-stereo panner with pan value in -1...1.
+/// - Input 0: input signal
+/// - Output 0: left channel
+/// - Output 1: right channel
 #[inline]
 pub fn pan(pan: f64) -> An<Panner<f64, U1>> {
     An(Panner::new(pan))
 }
 
 /// Parameter follower filter with halfway response time `t` seconds.
+/// - Input 0: input signal
+/// - Output 0: smoothed signal
 #[inline]
 pub fn follow<S: ScalarOrPair<Sample = f64>>(t: S) -> An<AFollow<f64, f64, S>> {
     An(AFollow::new(DEFAULT_SR, t))
@@ -674,6 +766,8 @@ pub fn follow<S: ScalarOrPair<Sample = f64>>(t: S) -> An<AFollow<f64, f64, S>> {
 
 /// Look-ahead limiter with `(attack, release)` times in seconds.
 /// Look-ahead is equal to the attack time.
+/// - Input 0: input signal
+/// - Output 0: signal limited to -1...1
 #[inline]
 pub fn limiter<S: ScalarOrPair<Sample = f64>>(time: S) -> An<Limiter<f64, U1, S>> {
     An(Limiter::new(DEFAULT_SR, time))
@@ -681,24 +775,32 @@ pub fn limiter<S: ScalarOrPair<Sample = f64>>(time: S) -> An<Limiter<f64, U1, S>
 
 /// Stereo look-ahead limiter with `(attack, release)` times in seconds.
 /// Look-ahead is equal to the attack time.
+/// - Input 0: left input signal
+/// - Input 1: right input signal
+/// - Output 0: left signal limited to -1...1
+/// - Output 0: right signal limited to -1...1
 #[inline]
 pub fn limiter_stereo<S: ScalarOrPair<Sample = f64>>(time: S) -> An<Limiter<f64, U2, S>> {
     An(Limiter::new(DEFAULT_SR, time))
 }
 
 /// Pinking filter.
+/// - Input 0: input signal
+/// - Output 0: filtered signal
 #[inline]
 pub fn pinkpass() -> An<Pinkpass<f64, f64>> {
     An(Pinkpass::new(DEFAULT_SR))
 }
 
 /// Pink noise.
+/// - Output 0: pink noise
 #[inline]
 pub fn pink() -> An<Pipe<f64, Noise<f64>, Pinkpass<f64, f64>>> {
     super::prelude::pink()
 }
 
 /// Brown noise.
+/// - Output 0: brown noise
 #[inline]
 pub fn brown() -> An<
     Pipe<f64, Noise<f64>, Binop<f64, FrameMul<U1, f64>, Lowpole<f64, f64, U1>, Constant<U1, f64>>>,
@@ -708,12 +810,17 @@ pub fn brown() -> An<
 }
 
 /// Frequency detector.
+/// - Input 0: input signal
+/// - Input 1: frequency to detect (Hz)
+/// - Output 0: signal power at the chosen frequency
 #[inline]
 pub fn goertzel() -> An<Goertzel<f64, f64>> {
     An(Goertzel::new(DEFAULT_SR))
 }
 
 /// Frequency detector of frequency `f` Hz.
+/// - Input 0: input signal
+/// - Output 0: signal power at the chosen frequency
 #[inline]
 pub fn goertzel_hz(
     f: f64,
@@ -935,6 +1042,10 @@ where
 /// Stereo reverb.
 /// `wet` in 0...1 is balance of reverb mixed in, for example, 0.1.
 /// `time` is approximate reverberation time to -60 dB in seconds.
+/// - Input 0: left input signal
+/// - Input 1: right input signal
+/// - Output 0: reverberated left signal
+/// - Output 1: reverberated right signal
 pub fn reverb_stereo(
     wet: f64,
     time: f64,
